<template>
	<view>
		<view class="page-body" style="margin-top: 4rpx;">
			<view class="page-section page-section-gap">
				<map style="width: 100%; height: 600px;" :latitude="latitude" :longitude="longitude" :markers="markers" :polyline="polyline"></map>
			</view>
		</view>
		<view class="tip">
			<view class="first">
				通行距离
				<text>{{ distance || '' }}Km</text>
			</view>
			<view class="first">
				预计到达时间
				<text>{{ duration || '' }}</text>
			</view>
		</view>
	</view>
</template>

<script>
export default {
	data() {
		return {
			latitude: 38.04606544104117,
			longitude: 114.48735479816793,
			customerId: '',
			filedId: '',
			orderType: '',
			toFiledId: '',
			// 起点经纬度
			originlongitude: 39.909,
			originlatitude: 116.39742,
			// 终点
			finishlongitude: null,
			finishlatitude: null,
			markers: [
				{
					latitude: null,
					longitude: null,
					iconPath: '../../../static/image/banner/location.png',
					width: 23,
					height: 33,
					id: 0,
					callout: {
						content: '起点', //文本
						color: '#ffffff', //文字颜色
						fontSize: 14, //文本大小
						borderRadius: 15, //边框圆角
						borderWidth: '10',
						bgColor: '#e51860', //背景颜色
						display: 'ALWAYS' //常显
					}
				},
				{
					latitude: null,
					longitude: null,
					iconPath: '../../../static/image/banner/location.png',
					width: 23,
					height: 33,
					id: 1,
					callout: {
						content: '终点', //文本
						color: '#ffffff', //文字颜色
						fontSize: 14, //文本大小
						borderRadius: 15, //边框圆角
						borderWidth: '10',
						bgColor: '#e51860', //背景颜色
						display: 'ALWAYS' //常显
					}
				}
			],
			polyline: [
				{
					// 每个点的经纬度
					points: [{ latitude: 38.04606544104117, longitude: 114.48735479816793 }, { latitude: 38.049531, longitude: 114.53521899999998 }],
					// 颜色
					color: '#0091ff',
					// 宽度
					width: 10
				}
			],
			distance: null,
			duration: null
		};
	},
	methods: {
		getLocation() {
			uni.showLoading({
				title: '加载中’'
			});
			let QQMapWX = require('../../../utils/qqmap-wx-jssdk.js');
			let qqmapsdk = new QQMapWX({
				key: 'HTNBZ-LZGRQ-YDB5S-B4KAS-KLHJH-GHBUE' // 必填
			});
			const params = this.toFiledId ? { toFiledId: this.toFiledId } : { customerId: this.customerId, filedId: this.filedId };
			this.$reqGet('getAppLocation', params).then(res => {
				console.log(res, '腾讯经纬度');
				let _this = this;
				let fromLocation;
				let toLocation;
				if (_this.orderType == '外购' || _this.orderType == '外销') {
					_this.$set(_this.markers[0], 'longitude', res.data.customerLongitude);
					_this.$set(_this.markers[0], 'latitude', res.data.customerLatitude);
					fromLocation = {
						longitude: res.data.customerLongitude,
						latitude: res.data.customerLatitude
					};
					_this.$set(_this.markers[1], 'longitude', res.data.filedLongitude);
					_this.$set(_this.markers[1], 'latitude', res.data.filedLatitude);
					toLocation = {
						longitude: res.data.filedLongitude,
						latitude: res.data.filedLatitude
					};
				} else if (_this.orderType == '内购' || _this.orderType == '内销') {
					_this.$set(_this.markers[0], 'longitude', res.data.filedLongitude);
					_this.$set(_this.markers[0], 'latitude', res.data.filedLatitude);
					fromLocation = {
						longitude: res.data.filedLongitude,
						latitude: res.data.filedLatitude
					};
					_this.$set(_this.markers[1], 'longitude', res.data.customerLongitude);
					_this.$set(_this.markers[1], 'latitude', res.data.customerLatitude);
					toLocation = {
						longitude: res.data.customerLongitude,
						latitude: res.data.customerLatitude
					};
				}
				//调用距离计算接口
				qqmapsdk.direction({
					mode: 'driving',
					//from参数不填默认当前地址
					from: fromLocation,
					to: toLocation,
					success: function(res) {
						console.log(res);
						let ret = res;
						let coors = ret.result.routes[0].polyline,
							pl = [];
						//坐标解压（返回的点串坐标，通过前向差分进行压缩）
						let kr = 1000000;
						for (let i = 2; i < coors.length; i++) {
							coors[i] = Number(coors[i - 2]) + Number(coors[i]) / kr;
						}
						//将解压后的坐标放入点串数组pl中
						for (let i = 0; i < coors.length; i += 2) {
							pl.push({ latitude: coors[i], longitude: coors[i + 1] });
						}
						console.log(pl);
						//设置polyline属性，将路线显示出来,将解压坐标第一个数据作为起点
						_this.longitude = pl[0].longitude;
						_this.latitude = pl[0].latitude;
						_this.polyline = [
							{
								points: pl,
								color: '#FF0000DD',
								width: 4,
								arrowLine: true
							}
						];
					},
					fail: function(error) {
						console.error(error);
					},
					complete: function(res) {
						console.log(res);
						uni.hideLoading();
						_this.distance = res.result.routes[0].distance;
						_this.distance = (_this.distance / 1000).toFixed(2);
						_this.duration = _this.handleTime(res.result.routes[0].duration);
					}
				});
			});
		},
		//
		handleTime(time) {
			let now = new Date(); // 获取当前时间
			now.setMinutes(now.getMinutes() + time);
			let hours = now
				.getHours()
				.toString()
				.padStart(2, '0');
			let minutes = now
				.getMinutes()
				.toString()
				.padStart(2, '0');
			return hours + ':' + minutes;
		}
	},
	onLoad(params) {
		this.customerId = params.customerId;
		this.filedId = params.filedId;
		this.orderType = params.orderType;
		if (params.toFiledId) {
			this.toFiledId = params.toFiledId;
		}
	},
	onShow() {
		if (this.orderType !== '转入' || this.orderType !== '转出') {
			this.getLocation();
		} else {
		}
	}
};
</script>

<style lang="scss" scoped>
.tip {
	margin-top: 60rpx;
	width: 94%;
	height: 40rpx;
	font-size: 40rpx;
	display: flex;
	justify-content: space-around;
	.first {
		color: #c78a64;
		text {
			font-size: 45rpx;
			color: #f81414;
		}
	}
}
</style>
